from setuptools import setup

setup(name='vishad_distributions',
      version='0.1',
      description='Test your Gaussian distributions',
      packages=['vishad_distributions'],
      zip_safe=False)
